@@ -336,10 +336,15 @@ void KEquityPriceUpdateDlg::slotConfigureClicked()
 void KEquityPriceUpdateDlg::slotQuoteFailed(const QString& _id, const QString& _symbol)
 {
   QListViewItem* item = lvEquityList->findItem(_id,ID_COL,Qt::ExactMatch);
-  
+
   // Give the user some options
 
-  int result = KMessageBox::questionYesNoCancel(this,i18n("Failed to retrieve a quote for %1 from %2.  Would you like to disable online price updates for this security?").arg(_symbol,item->text(SOURCE_COL)),i18n("Price Update Failed"),KStdGuiItem::yes(),KStdGuiItem::no(),"KEquityPriceUpdateDlg::slotQuoteFailed::Price Update Failed");
+  int result;
+  if(_id.contains(" ")) {
+    result = KMessageBox::warningContinueCancel(this,i18n("Failed to retrieve an exchange rate for %1 from %2. It will be skipped this time.").arg(_symbol,item->text(SOURCE_COL)),i18n("Price Update  Failed"));
+  } else {
+    result = KMessageBox::questionYesNoCancel(this,i18n("Failed to retrieve a quote for %1 from %2.  Would you like to disable online price updates for this security?").arg(_symbol,item->text(SOURCE_COL)),i18n("Price Update Failed"),KStdGuiItem::yes(),KStdGuiItem::no(),"KEquityPriceUpdateDlg::slotQuoteFailed::Price Update Failed");
+  }
 
   if ( result == KMessageBox::Yes )
   {
@@ -347,21 +352,21 @@ void KEquityPriceUpdateDlg::slotQuoteFailed(const QString& _id, const QString& _
 
     // Get this security (by ID)
     MyMoneySecurity security = MyMoneyFile::instance()->security(_id.utf8());
-    
+
     // Set the quote source to blank
     security.setValue("kmm-online-source",QString());
-    
+
     // Re-commit the security
     MyMoneyFile::instance()->modifySecurity(security);
   }
-  
+
   // As long as the user doesn't want to cancel, move on!
   if ( result != KMessageBox::Cancel )
   {
     QListViewItem* next = NULL;
     prgOnlineProgress->advance(1);
     item->listView()->setSelected(item, false);
- 
+
     // launch the NEXT one ... in case of m_fUpdateAll == false, we
     // need to parse the list to find the next selected one
     next = item->nextSibling();
