@@ -299,24 +299,6 @@ public:
     */
   static int occurenceToFrequency(const MyMoneySchedule::occurenceE occurence);
 
-  /**
-    * This method returns the applications default background color if
-    * none has been setup by the user.
-    */
-  static const QColor defaultBackgroundColour(void);
-
-  /**
-    * This method returns the applications default list color if
-    * none has been setup by the user.
-    */
-  static const QColor defaultListColour(void);
-
-  /**
-    * This method returns the applications default grid color if
-    * none has been setup by the user.
-    */
-  static const QColor defaultGridColour(void);
-
   /**
     * This method is used to update all settings when they are
     * changed by the user through the respective settings dialog.
@@ -337,6 +319,10 @@ public:
     return _gridColour;
   }
 
+  static const QColor missingConversionColour(void) {
+    return _missingConversionColour;
+  }
+
   static const QFont& cellFont(void) { return _cellFont; };
   static const QFont& headerFont(void) { return _headerFont; };
 
@@ -412,6 +398,7 @@ private:
   static QColor _backgroundColour;
   static QColor _listColour;
   static QColor _gridColour;
+  static QColor _missingConversionColour;
 
   static QFont  _cellFont;
   static QFont  _headerFont;
