@@ -61,6 +61,15 @@ QTime timer;
 
 KMyMoney2App* kmymoney2;
 
+static void _cleanup(void)
+{
+#ifdef _CHECK_MEMORY
+  chkmem.CheckMemoryLeak( false );
+  _CheckMemory_End();
+#endif
+}
+
+
 int main(int argc, char *argv[])
 {
   QString feature;
@@ -74,7 +83,7 @@ int main(int argc, char *argv[])
 
   KAboutData aboutData( "kmymoney2", I18N_NOOP("KMyMoney"),
     VERSION, description, KAboutData::License_GPL,
-    "(c) 2000-2005 The KMyMoney development team", feature,
+    "(c) 2000-2006 The KMyMoney development team", feature,
     "http://kmymoney2.sourceforge.net/",
     "kmymoney2-developer@lists.sourceforge.net");
 
@@ -100,6 +109,7 @@ int main(int argc, char *argv[])
 #ifdef _CHECK_MEMORY
   _CheckMemory_Init(0);
 #endif
+  atexit(_cleanup);
 
   KMyMoneyUtils::checkConstants();
 
@@ -170,12 +180,16 @@ int main(int argc, char *argv[])
             if (!client->send(primary, "kmymoney2app", "webConnect(QString,QCString)",data))
               qDebug("Unable to launch WebConnect via DCOP.");
 
+            delete kmymoney2;
+            delete splash;
             break;
           }
         }
 
         if(KMessageBox::questionYesNo(0, i18n("Another instance of KMyMoney is already running. Do you want to quit?")) == KMessageBox::Yes) {
           rc = 1;
+          delete kmymoney2;
+          delete splash;
           break;
         }
       }
@@ -232,11 +246,6 @@ int main(int argc, char *argv[])
 
   delete a;
 
-#ifdef _CHECK_MEMORY
-  chkmem.CheckMemoryLeak( false );
-  _CheckMemory_End();
-#endif
-
   return rc;
 }
 
