@@ -31,7 +31,7 @@
 
 #include "mymoneyfile.h"
 #include "mymoneyreport.h"
- 
+
 //ReportContainer gContainer;
 
 const QStringList MyMoneyReport::kRowTypeText = QStringList::split(",","none,assetliability,expenseincome,category,topcategory,account,payee,month,week,topaccount,topaccount-account,equitytype,accounttype,institution",true);
@@ -60,7 +60,7 @@ MyMoneyReport::MyMoneyReport(void):
     m_accountGroupFilter(false)
 {
 }
-  
+
 MyMoneyReport::MyMoneyReport(ERowType _rt, unsigned _ct, unsigned _dl, bool _ss, const QString& _name, const QString& _comment ):
     m_name(_name),
     m_comment(_comment),
@@ -137,7 +137,7 @@ void MyMoneyReport::validDateRange(QDate& _db, QDate& _de)
   }
   if ( _db > _de )
     _db = _de;
-} 
+}
 
 void MyMoneyReport::setRowType(ERowType _rt)
 {
@@ -146,7 +146,7 @@ void MyMoneyReport::setRowType(ERowType _rt)
 
   m_accountGroupFilter = false;
   m_accountGroups.clear();
-  
+
   if ( _rt == MyMoneyReport::eAssetLiability )
   {
     addAccountGroup(MyMoneyAccount::Asset);
@@ -225,14 +225,14 @@ const bool MyMoneyReport::includes( const MyMoneyAccount& acc ) const
 void MyMoneyReport::write(QDomElement& e, QDomDocument *doc, bool anonymous) const
 {
   // No matter what changes, be sure to have a 'type' attribute.  Only change
-  // the major type if it becomes impossible to maintain compatability with 
+  // the major type if it becomes impossible to maintain compatability with
   // older versions of the program as new features are added to the reports.
   // Feel free to change the minor type every time a change is made here.
 
   if ( m_reportType == ePivotTable )
   {
     e.setAttribute("type","pivottable 1.7");
-    
+
     if ( anonymous )
     {
       e.setAttribute("name", m_id);
@@ -275,7 +275,7 @@ void MyMoneyReport::write(QDomElement& e, QDomDocument *doc, bool anonymous) con
     e.setAttribute("rowtype", kRowTypeText[m_rowType]);
     e.setAttribute("id", m_id);
     e.setAttribute("datelock", kDateLockText[m_dateLock]);
-    
+
     QStringList columns;
     unsigned qc = m_queryColumns;
     unsigned it_qc = eQCbegin;
@@ -289,11 +289,11 @@ void MyMoneyReport::write(QDomElement& e, QDomDocument *doc, bool anonymous) con
     }
     e.setAttribute("querycolumns", columns.join(","));
   }
-     
+
   //
   // Text Filter
   //
-    
+
   QRegExp textfilter;
   if ( textFilter(textfilter))
   {
@@ -317,10 +317,10 @@ void MyMoneyReport::write(QDomElement& e, QDomDocument *doc, bool anonymous) con
       QDomElement p = doc->createElement("TYPE");
       p.setAttribute("type", kTypeText[*it_type]);
       e.appendChild(p);
-      
+
       ++it_type;
     }
-  }      
+  }
 
   QValueList<int> statelist;
   if ( states(statelist) && ! statelist.empty() )
@@ -332,14 +332,14 @@ void MyMoneyReport::write(QDomElement& e, QDomDocument *doc, bool anonymous) con
       QDomElement p = doc->createElement("STATE");
       p.setAttribute("state", kStateText[*it_state]);
       e.appendChild(p);
-      
+
       ++it_state;
     }
-  }      
+  }
   //
   // Number Filter
   //
-    
+
   QString nrFrom, nrTo;
   if ( numberFilter(nrFrom, nrTo) )
   {
@@ -348,7 +348,7 @@ void MyMoneyReport::write(QDomElement& e, QDomDocument *doc, bool anonymous) con
     f.setAttribute("to", nrTo);
     e.appendChild(f);
   }
-  
+
   //
   // Amount Filter
   //
@@ -365,7 +365,7 @@ void MyMoneyReport::write(QDomElement& e, QDomDocument *doc, bool anonymous) con
   //
   // Payees Filter
   //
-  
+
   QCStringList payeelist;
   if ( payees(payeelist) )
   {
@@ -383,16 +383,16 @@ void MyMoneyReport::write(QDomElement& e, QDomDocument *doc, bool anonymous) con
         QDomElement p = doc->createElement("PAYEE");
         p.setAttribute("id", *it_payee);
         e.appendChild(p);
-        
+
         ++it_payee;
-      }      
+      }
     }
   }
 
   //
   // Account Groups Filter
   //
-  
+
   QValueList<MyMoneyAccount::accountTypeE> accountgrouplist;
   if ( accountGroups(accountgrouplist) )
   {
@@ -403,15 +403,15 @@ void MyMoneyReport::write(QDomElement& e, QDomDocument *doc, bool anonymous) con
       QDomElement p = doc->createElement("ACCOUNTGROUP");
       p.setAttribute("group", kAccountTypeText[*it_group]);
       e.appendChild(p);
-      
+
       ++it_group;
-    }      
+    }
   }
 
   //
   // Accounts Filter
   //
-  
+
   QCStringList accountlist;
   if ( accounts(accountlist) )
   {
@@ -422,15 +422,15 @@ void MyMoneyReport::write(QDomElement& e, QDomDocument *doc, bool anonymous) con
       QDomElement p = doc->createElement("ACCOUNT");
       p.setAttribute("id", *it_account);
       e.appendChild(p);
-      
+
       ++it_account;
-    }      
+    }
   }
 
   //
   // Categories Filter
   //
-        
+
   accountlist.clear();
   if ( categories(accountlist) )
   {
@@ -441,15 +441,15 @@ void MyMoneyReport::write(QDomElement& e, QDomDocument *doc, bool anonymous) con
       QDomElement p = doc->createElement("CATEGORY");
       p.setAttribute("id", *it_account);
       e.appendChild(p);
-      
+
       ++it_account;
-    }      
+    }
   }
-    
+
   //
   // Date Filter
   //
-    
+
   if ( m_dateLock == userDefined )
   {
     QDate dateFrom, dateTo;
@@ -471,18 +471,18 @@ bool MyMoneyReport::read(const QDomElement& e)
   // compatability.  Any report ever created with any version of KMyMoney
   // should be able to be loaded by this method (as long as it's one of the
   // report types supported in this version, of course)
-        
+
   bool result = false;
-  
-  if ( 
-    QString("REPORT") == e.tagName() 
-    && 
+
+  if (
+    QString("REPORT") == e.tagName()
+    &&
     (
       (  e.attribute("type").find(QString("pivottable 1.")) == 0 )
       ||
       (  e.attribute("type").find(QString("querytable 1.")) == 0 )
     )
-  )      
+  )
   {
     result = true;
     clear();
@@ -490,7 +490,7 @@ bool MyMoneyReport::read(const QDomElement& e)
     int i;
     m_name = e.attribute("name");
     m_comment = e.attribute("comment","Extremely old report");
-    
+
     // Removed the line that screened out loading reports that are called
     // "Default Report".  It's possible for the user to change the comment
     // to this, and we'd hate for it to break as a result.
@@ -500,9 +500,9 @@ bool MyMoneyReport::read(const QDomElement& e)
     m_showSubAccounts = e.attribute("showsubaccounts","0").toUInt();
     m_convertCurrency = e.attribute("convertcurrency","1").toUInt();
     m_favorite = e.attribute("favorite","0").toUInt();
-    m_tax = e.attribute("tax","0").toUInt();    
+    m_tax = e.attribute("tax","0").toUInt();
     m_investments = e.attribute("investments","0").toUInt();
-    
+
     QString datelockstr = e.attribute("datelock","userdefined");
     // Handle the pivot 1.2/query 1.1 case where the values were saved as
     // numbers
@@ -515,17 +515,17 @@ bool MyMoneyReport::read(const QDomElement& e)
         i = userDefined;
     }
     setDateFilter( i );
-    
+
     i = kRowTypeText.findIndex(e.attribute("rowtype","expenseincome"));
     if ( i != -1 )
     {
       setRowType( static_cast<ERowType>(i) );
     }
-    
-    i = kColumnTypeText.findIndex(e.attribute("columntype","months"));      
+
+    i = kColumnTypeText.findIndex(e.attribute("columntype","months"));
     if ( i != -1 )
       setColumnType( static_cast<EColumnType>(i) );
-    
+
     unsigned qc = 0;
     QStringList columns = QStringList::split(",",e.attribute("querycolumns","none"));
     QStringList::const_iterator it_column = columns.begin();
@@ -534,7 +534,7 @@ bool MyMoneyReport::read(const QDomElement& e)
       i = kQueryColumnsText.findIndex(*it_column);
       if ( i > 0 )
         qc |= ( 1 << (i-1) );
-    
+
       ++it_column;
     }
     setQueryColumns( static_cast<EQueryColumns>(qc) );
@@ -561,11 +561,11 @@ bool MyMoneyReport::read(const QDomElement& e)
       }
       if(QString("NUMBER") == c.tagName())
       {
-        setNumberFilter(c.attribute("from"),c.attribute("to"));        	
+        setNumberFilter(c.attribute("from"),c.attribute("to"));
       }
       if(QString("AMOUNT") == c.tagName())
       {
-        setAmountFilter(MyMoneyMoney(c.attribute("from","0/100")),MyMoneyMoney(c.attribute("to","0/100")));        	
+        setAmountFilter(MyMoneyMoney(c.attribute("from","0/100")),MyMoneyMoney(c.attribute("to","0/100")));
       }
       if(QString("DATES") == c.tagName())
       {
@@ -597,7 +597,14 @@ bool MyMoneyReport::read(const QDomElement& e)
       child = child.nextSibling();
     }
   }
-  return result;  
+  return result;
+}
+
+void MyMoneyReport::removeAccount( const QCString& id)
+{
+  if(m_accounts.find(id) != 0) {
+    m_accounts.remove(id);
+  }
 }
 
 // vim:cin:si:ai:et:ts=2:sw=2:
