@@ -45,8 +45,8 @@ using namespace test;
 
 namespace querytabletest
 {
-const MyMoneyMoney moCheckingOpen(1418.0);
-const MyMoneyMoney moCreditOpen(-418.0);
+const MyMoneyMoney moCheckingOpen(0.0);
+const MyMoneyMoney moCreditOpen(0.0);
 const MyMoneyMoney moZero(0.0);
 const MyMoneyMoney moSolo(234.12);
 const MyMoneyMoney moParent1(88.01);
@@ -159,16 +159,13 @@ void QueryTableTest::testQueryBasics()
     QueryTable qtbl_1(filter);
 
     writeTabletoHTML(qtbl_1,"Transactions by Category.html");   
-    CPPUNIT_ASSERT(qtbl_1.m_transactions.count() == 14);
-    CPPUNIT_ASSERT(qtbl_1.m_transactions[0]["categorytype"]=="Equity");
-    CPPUNIT_ASSERT(qtbl_1.m_transactions[0]["category"]=="Opening Balances");
-    CPPUNIT_ASSERT(qtbl_1.m_transactions[0]["postdate"]=="2004-05-15");
-    CPPUNIT_ASSERT(qtbl_1.m_transactions[2]["categorytype"]=="Expense");
-    CPPUNIT_ASSERT(qtbl_1.m_transactions[2]["category"]=="Parent");
-    CPPUNIT_ASSERT(qtbl_1.m_transactions[2]["postdate"]=="2004-02-01");
-    CPPUNIT_ASSERT(qtbl_1.m_transactions[13]["categorytype"]=="Expense");
-    CPPUNIT_ASSERT(qtbl_1.m_transactions[13]["category"]=="Solo");
-    CPPUNIT_ASSERT(qtbl_1.m_transactions[13]["postdate"]=="2005-01-01");
+    CPPUNIT_ASSERT(qtbl_1.m_transactions.count() == 12);
+    CPPUNIT_ASSERT(qtbl_1.m_transactions[0]["categorytype"]=="Expense");
+    CPPUNIT_ASSERT(qtbl_1.m_transactions[0]["category"]=="Parent");
+    CPPUNIT_ASSERT(qtbl_1.m_transactions[0]["postdate"]=="2004-02-01");
+    CPPUNIT_ASSERT(qtbl_1.m_transactions[11]["categorytype"]=="Expense");
+    CPPUNIT_ASSERT(qtbl_1.m_transactions[11]["category"]=="Solo");
+    CPPUNIT_ASSERT(qtbl_1.m_transactions[11]["postdate"]=="2005-01-01");
 
     QString html = qtbl_1.renderHTML();
     CPPUNIT_ASSERT( searchHTML(html,i18n("Total")+" Parent") == -(moParent1 + moParent2) * 3 );
@@ -184,16 +181,16 @@ void QueryTableTest::testQueryBasics()
     QueryTable qtbl_2(filter);
    
     writeTabletoHTML(qtbl_2,"Transactions by Top Category.html");   
-    CPPUNIT_ASSERT(qtbl_2.m_transactions.count() == 14);
-    CPPUNIT_ASSERT(qtbl_2.m_transactions[2]["categorytype"]=="Expense");
-    CPPUNIT_ASSERT(qtbl_2.m_transactions[2]["topcategory"]=="Parent");
-    CPPUNIT_ASSERT(qtbl_2.m_transactions[2]["postdate"]=="2004-02-01");
-    CPPUNIT_ASSERT(qtbl_2.m_transactions[10]["categorytype"]=="Expense");
-    CPPUNIT_ASSERT(qtbl_2.m_transactions[10]["topcategory"]=="Parent");
-    CPPUNIT_ASSERT(qtbl_2.m_transactions[10]["postdate"]=="2005-09-01");
-    CPPUNIT_ASSERT(qtbl_2.m_transactions[13]["categorytype"]=="Expense");
-    CPPUNIT_ASSERT(qtbl_2.m_transactions[13]["topcategory"]=="Solo");
-    CPPUNIT_ASSERT(qtbl_2.m_transactions[13]["postdate"]=="2005-01-01");
+    CPPUNIT_ASSERT(qtbl_2.m_transactions.count() == 12);
+    CPPUNIT_ASSERT(qtbl_2.m_transactions[0]["categorytype"]=="Expense");
+    CPPUNIT_ASSERT(qtbl_2.m_transactions[0]["topcategory"]=="Parent");
+    CPPUNIT_ASSERT(qtbl_2.m_transactions[0]["postdate"]=="2004-02-01");
+    CPPUNIT_ASSERT(qtbl_2.m_transactions[8]["categorytype"]=="Expense");
+    CPPUNIT_ASSERT(qtbl_2.m_transactions[8]["topcategory"]=="Parent");
+    CPPUNIT_ASSERT(qtbl_2.m_transactions[8]["postdate"]=="2005-09-01");
+    CPPUNIT_ASSERT(qtbl_2.m_transactions[11]["categorytype"]=="Expense");
+    CPPUNIT_ASSERT(qtbl_2.m_transactions[11]["topcategory"]=="Solo");
+    CPPUNIT_ASSERT(qtbl_2.m_transactions[11]["postdate"]=="2005-01-01");
 
     html = qtbl_2.renderHTML();
     CPPUNIT_ASSERT( searchHTML(html,i18n("Total")+" Parent") == -(moParent1 + moParent2 + moChild) * 3 );
@@ -209,13 +206,13 @@ void QueryTableTest::testQueryBasics()
     QueryTable qtbl_3(filter);
     
     writeTabletoHTML(qtbl_3,"Transactions by Account.html");   
-    CPPUNIT_ASSERT(qtbl_3.m_transactions.count() == 14);
+    CPPUNIT_ASSERT(qtbl_3.m_transactions.count() == 12);
     CPPUNIT_ASSERT(qtbl_3.m_transactions[0]["account"]=="Checking Account");
     CPPUNIT_ASSERT(qtbl_3.m_transactions[0]["category"]=="Solo");
     CPPUNIT_ASSERT(qtbl_3.m_transactions[0]["postdate"]=="2004-01-01");
-    CPPUNIT_ASSERT(qtbl_3.m_transactions[13]["account"]=="Credit Card");
-    CPPUNIT_ASSERT(qtbl_3.m_transactions[13]["category"]=="Parent");
-    CPPUNIT_ASSERT(qtbl_3.m_transactions[13]["postdate"]=="2005-09-01");
+    CPPUNIT_ASSERT(qtbl_3.m_transactions[11]["account"]=="Credit Card");
+    CPPUNIT_ASSERT(qtbl_3.m_transactions[11]["category"]=="Parent");
+    CPPUNIT_ASSERT(qtbl_3.m_transactions[11]["postdate"]=="2005-09-01");
 
     html = qtbl_3.renderHTML();
     CPPUNIT_ASSERT( searchHTML(html,i18n("Total")+" Checking Account") == -(moSolo) * 3 + moCheckingOpen);
@@ -230,7 +227,7 @@ void QueryTableTest::testQueryBasics()
     QueryTable qtbl_4(filter);
 
     writeTabletoHTML(qtbl_4,"Transactions by Payee.html");   
-    CPPUNIT_ASSERT(qtbl_4.m_transactions.count() == 14);
+    CPPUNIT_ASSERT(qtbl_4.m_transactions.count() == 12);
     CPPUNIT_ASSERT(qtbl_4.m_transactions[0]["payee"]=="Test Payee");
     CPPUNIT_ASSERT(qtbl_4.m_transactions[0]["category"]=="Solo");
     CPPUNIT_ASSERT(qtbl_4.m_transactions[0]["postdate"]=="2004-01-01");
@@ -240,9 +237,6 @@ void QueryTableTest::testQueryBasics()
     CPPUNIT_ASSERT(qtbl_4.m_transactions[11]["payee"]=="Test Payee");
     CPPUNIT_ASSERT(qtbl_4.m_transactions[11]["category"]=="Parent");
     CPPUNIT_ASSERT(qtbl_4.m_transactions[11]["postdate"]=="2005-09-01");
-    CPPUNIT_ASSERT(qtbl_4.m_transactions[13]["payee"]=="[Empty Payee]");
-    CPPUNIT_ASSERT(qtbl_4.m_transactions[13]["category"]=="Opening Balances");
-    CPPUNIT_ASSERT(qtbl_4.m_transactions[13]["postdate"]=="2004-07-15");
 
     html = qtbl_4.renderHTML();
     CPPUNIT_ASSERT( searchHTML(html,i18n("Total")+" Test Payee") == -(moParent1 + moParent2 + moSolo + moChild) * 3 );
@@ -256,16 +250,16 @@ void QueryTableTest::testQueryBasics()
     QueryTable qtbl_5(filter);
     
     writeTabletoHTML(qtbl_5,"Transactions by Month.html");
-    CPPUNIT_ASSERT(qtbl_5.m_transactions.count() == 14);
+    CPPUNIT_ASSERT(qtbl_5.m_transactions.count() == 12);
     CPPUNIT_ASSERT(qtbl_5.m_transactions[0]["payee"]=="Test Payee");
     CPPUNIT_ASSERT(qtbl_5.m_transactions[0]["category"]=="Solo");
     CPPUNIT_ASSERT(qtbl_5.m_transactions[0]["postdate"]=="2004-01-01");
-    CPPUNIT_ASSERT(qtbl_5.m_transactions[10]["payee"]=="Test Payee");
-    CPPUNIT_ASSERT(qtbl_5.m_transactions[10]["category"]=="Parent: Child");
-    CPPUNIT_ASSERT(qtbl_5.m_transactions[10]["postdate"]=="2004-11-07");
-    CPPUNIT_ASSERT(qtbl_5.m_transactions[13]["payee"]=="Test Payee");
-    CPPUNIT_ASSERT(qtbl_5.m_transactions[13]["category"]=="Parent");
-    CPPUNIT_ASSERT(qtbl_5.m_transactions[13]["postdate"]=="2005-09-01");
+    CPPUNIT_ASSERT(qtbl_5.m_transactions[8]["payee"]=="Test Payee");
+    CPPUNIT_ASSERT(qtbl_5.m_transactions[8]["category"]=="Parent: Child");
+    CPPUNIT_ASSERT(qtbl_5.m_transactions[8]["postdate"]=="2004-11-07");
+    CPPUNIT_ASSERT(qtbl_5.m_transactions[11]["payee"]=="Test Payee");
+    CPPUNIT_ASSERT(qtbl_5.m_transactions[11]["category"]=="Parent");
+    CPPUNIT_ASSERT(qtbl_5.m_transactions[11]["postdate"]=="2005-09-01");
 
     html = qtbl_5.renderHTML();
     CPPUNIT_ASSERT( searchHTML(html,i18n("Total")+" Month of 2004-01-01") == -moSolo );
@@ -281,16 +275,13 @@ void QueryTableTest::testQueryBasics()
     QueryTable qtbl_6(filter);
     
     writeTabletoHTML(qtbl_6,"Transactions by Week.html");
-    CPPUNIT_ASSERT(qtbl_6.m_transactions.count() == 14);
+    CPPUNIT_ASSERT(qtbl_6.m_transactions.count() == 12);
     CPPUNIT_ASSERT(qtbl_6.m_transactions[0]["payee"]=="Test Payee");
     CPPUNIT_ASSERT(qtbl_6.m_transactions[0]["category"]=="Solo");
     CPPUNIT_ASSERT(qtbl_6.m_transactions[0]["postdate"]=="2004-01-01");
-    CPPUNIT_ASSERT(qtbl_6.m_transactions[7]["payee"]=="[Empty Payee]");
-    CPPUNIT_ASSERT(qtbl_6.m_transactions[7]["category"]=="Opening Balances");
-    CPPUNIT_ASSERT(qtbl_6.m_transactions[7]["postdate"]=="2004-07-15");
-    CPPUNIT_ASSERT(qtbl_6.m_transactions[13]["payee"]=="Test Payee");
-    CPPUNIT_ASSERT(qtbl_6.m_transactions[13]["category"]=="Parent");
-    CPPUNIT_ASSERT(qtbl_6.m_transactions[13]["postdate"]=="2005-09-01");
+    CPPUNIT_ASSERT(qtbl_6.m_transactions[11]["payee"]=="Test Payee");
+    CPPUNIT_ASSERT(qtbl_6.m_transactions[11]["category"]=="Parent");
+    CPPUNIT_ASSERT(qtbl_6.m_transactions[11]["postdate"]=="2005-09-01");
 
     html = qtbl_6.renderHTML();
     CPPUNIT_ASSERT( searchHTML(html,i18n("Total")+" Week of 2003-12-29") == -moSolo );
