@@ -29,6 +29,7 @@
 #include <dom/dom_element.h>
 #include <dom/dom_doc.h>
 #include <dom/dom_text.h>
+#include <qtimer.h>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -74,13 +75,19 @@ KHomeView::~KHomeView()
 {
 }
 
-void KHomeView::show()
+void KHomeView::show(void)
 {
   slotRefreshView();
   QWidget::show();
   emit signalViewActivated();
 }
 
+void KHomeView::slotPrintView(void)
+{
+  if(m_part && m_part->view())
+    m_part->view()->print();
+}
+
 void KHomeView::slotRefreshView(void)
 {
   if(MyMoneyFile::instance()->accountList().count() == 0) {
@@ -587,7 +594,7 @@ void KHomeView::slotOpenURL(const KURL &url, const KParts::URLArgs& /* args */)
     } else if(view == "action") {
         KMainWindow* mw = dynamic_cast<KMainWindow*>(qApp->mainWidget());
         Q_CHECK_PTR(mw);
-        mw->actionCollection()->action( id )->activate();
+        QTimer::singleShot(0, mw->actionCollection()->action( id ), SLOT(activate()));
 
 #if 0
         // Enable this to get a dump of all action names
