@@ -65,7 +65,7 @@ KScheduledView::KScheduledView(QWidget *parent, const char *name )
   m_qlistviewScheduled->addColumn(i18n("Frequency"));
   m_qlistviewScheduled->addColumn(i18n("Payment Method"));
   m_qlistviewScheduled->setMultiSelection(false);
-  m_qlistviewScheduled->header()->setResizeEnabled(false);
+  m_qlistviewScheduled->header()->setResizeEnabled(true);
   m_qlistviewScheduled->setAllColumnsShowFocus(true);
   // never show a horizontal scroll bar
   m_qlistviewScheduled->setHScrollBarMode(QScrollView::AlwaysOff);
@@ -116,11 +116,8 @@ KScheduledView::~KScheduledView()
 
 void KScheduledView::refresh(bool full, const QCString schedId)
 {
-  KConfig *config = KGlobal::config();
-  config->setGroup("List Options");
-  QFont headerFont(m_qlistviewScheduled->font());
-  headerFont = config->readFontEntry("listHeaderFont", &headerFont);
-  m_qlistviewScheduled->header()->setFont(headerFont);
+  m_qlistviewScheduled->header()->setFont(KMyMoneyUtils::headerFont());
+  m_qlistviewScheduled->setFont(KMyMoneyUtils::cellFont());
 
   m_qlistviewScheduled->clear();
 
@@ -411,9 +408,9 @@ void KScheduledView::readConfig(void)
   m_openLoans = config->readBoolEntry("KScheduleView_openLoans", true);
 
   config->setGroup("List Options");
-  QFont headerFont(m_qlistviewScheduled->font());
-  headerFont = config->readFontEntry("listHeaderFont", &headerFont);
-  m_qlistviewScheduled->header()->setFont(headerFont);
+
+  m_qlistviewScheduled->header()->setFont(KMyMoneyUtils::headerFont());
+  m_qlistviewScheduled->setFont(KMyMoneyUtils::cellFont());
 }
 
 void KScheduledView::writeConfig(void)
