@@ -74,6 +74,7 @@ kMyMoneyDateInput::kMyMoneyDateInput(QWidget *parent, const char *name, Qt::Alig
   for(unsigned i = 0; i < dateFormat.length(); ++i) {
     // DD.MM.YYYY is %d.%m.%y
     // dD.mM.YYYY is %e.%n.%y
+    // SHORTWEEKDAY, dD SHORTMONTH YYYY is %a, %e %b %Y
     if(dateFormat[i] == 'y' || dateFormat[i] == 'm' || dateFormat[i] == 'n' || dateFormat[i] == 'd' || dateFormat[i] == 'e') {
       if(dateFormat[i] == 'n')
         dateFormat[i] = 'm';
@@ -100,6 +101,7 @@ kMyMoneyDateInput::kMyMoneyDateInput(QWidget *parent, const char *name, Qt::Alig
   } else {
     dateEdit->setOrder(QDateEdit::YMD);
     m_focusDatePart = 2;
+    separator = '-';
   }
   dateEdit->setSeparator(separator);
 
@@ -213,13 +215,11 @@ void kMyMoneyDateInput::keyPressEvent(QKeyEvent * k)
   KShortcut today(i18n("Enter todays date into date input widget", "T"));
 
   switch(k->key()) {
-    case Key_Up:
     case Key_Equal:
     case Key_Plus:
       slotDateChosen(m_date.addDays(1));
       break;
 
-    case Key_Down:
     case Key_Minus:
       slotDateChosen(m_date.addDays(-1));
       break;
@@ -251,7 +251,7 @@ bool kMyMoneyDateInput::eventFilter(QObject *, QEvent *e)
     m_datePopup->hide();
   else if (e->type() == QEvent::KeyPress) {
     if (QKeyEvent *k = dynamic_cast<QKeyEvent*>(e)) {
-      if (k->key() == Key_Up || k->key() == Key_Down || k->key() == Key_Minus) {
+      if (k->key() == Key_Minus) {
         keyPressEvent(k);
         return true;
       }
